@@ -1,6 +1,6 @@
 test_that("API call fails gracefully", {
   skip_on_cran() # because API key...
-  skip_if(is.character(RCurl::getURL("www.google.com")), "the internet is on") # othervise it would be no fun...
+  skip_if(RCurl::url.exists("www.google.com"), "the internet is on") # othervise it would be no fun...
 
   expect_message( # i.e. do not expect an error!!!
 
